@@ -61,6 +61,7 @@ class CashflowManager {
 
     /**
      * Fetch and deserialize the next locale in the list (if present).
+     * @param {array} initLocaleStrAry Locale string array.
      */    
      initLocale(initLocaleStrAry) {
 
@@ -118,8 +119,20 @@ class CashflowManager {
                                         Toaster.toastError(Updater.getResource(this, MSG_HELP_LOAD));
                                         return;
                                     }
-                        
-                                    response.text().then(text => this.initEngine(localeStr, text));
+                                    
+                                    response.text().then(text => {                                                                
+                                        config.helpForms = JSON.parse(text);
+                                        
+                                        let queryParams = new URLSearchParams(window.location.search);
+                                        let clearLists = queryParams.has("clear");
+                                        let urls = queryParams.getAll("url");
+
+                                        if (clearLists) {
+                                            this.engine.clear_lists();
+                                        }
+
+                                        this.initUrls(localeStr, urls);
+                                    });
                                 });
                             });
                         });
@@ -129,19 +142,49 @@ class CashflowManager {
         });
     }
 
+    /**
+     * Initialize additional urls.
+     * @param {string} localeStr Locale string.
+     * @param {array} urls Additional urls.
+     */    
+    initUrls(localeStr, urls) {
+        let url = urls.shift();
+        if (!url) {
+            this.initEngine(localeStr);
+            return;
+        }
+
+        fetch(url).then(response => {
+            if (!response.ok) {
+                Toaster.toastError(Updater.getResource(this, MSG_LOCALES_LOAD));
+                this.initEngine(localeStr);
+                return;
+            }
+            
+            response.text().then(text => {                                                                
+                let result = this.engine.deserialize(text);
+                if (result.length > 0) {
+                    Toaster.toastError(result);
+                    this.initEngine(localeStr);
+                    return;
+                }  
+
+                this.initUrls(localeStr, urls);
+            });
+        });
+    }
+
     /**
      * Initialize the AmFn engine.
      * @param {string} localeStr Locale string.
-     * @param {string} text Text from help context fetch.
      */    
-    initEngine(localeStr, text) {
+    initEngine(localeStr) {
         let initInfo =  this.engine.init().split('|');
         if (initInfo.length === 3) {    
             config.localeStr = initInfo[0];                
             config.encoding = initInfo[1];                
             config.decimalDigits = parseInt(initInfo[2]);
 
-            config.helpForms = JSON.parse(text);
             config.helpTitleInfo = Updater.getResource(this, HELP_TITLE_INFO);
             config.helpTitleError = Updater.getResource(this, HELP_TITLE_ERROR);
 
@@ -347,10 +390,12 @@ class CashflowManager {
         }
     
         this.activeTabIndex = index;
-        this.setExpand(this.tabs[this.activeTabIndex].expanded);
+        let tab = this.tabs[this.activeTabIndex];
+
+        this.setExpand(tab.expanded);
     
         let chartDefHtml = "";
-        for (let chartDef of this.tabs[this.activeTabIndex].chartDefs) {  
+        for (let chartDef of tab.chartDefs) {  
             let chartIcon = chartDef.allCashflows ? "bi-share" : "bi-graph-up";  
             chartDefHtml += `<li><a class="dropdown-item chart-item" href="#" data-name="` + 
                 chartDef.name + `"><i class="` + chartIcon + `"></i> ` + chartDef.description + `</a></li>`;
@@ -370,10 +415,21 @@ class CashflowManager {
             if (!tab.grdAm.classList.contains("display-none")) tab.grdAm.classList.add("display-none");
         }
     
-        this.tabs[this.activeTabIndex].grdEvent.classList.remove("display-none");
-        this.tabs[this.activeTabIndex].grdAm.classList.remove("display-none");
+        tab.grdEvent.classList.remove("display-none");
+        tab.grdAm.classList.remove("display-none");
     
         Updater.refreshStatusLine(this);  
+
+        let enable = !!tab.lastFocused.colDef;
+        let enableCalc = false;
+        
+        if (enable) {
+            let field = tab.lastFocused.colDef.col_name;
+            enableCalc = field === FIELD_VALUE || field === FIELD_PERIODS;
+        }
+
+        cashflowManager.enableClass("btnDelete", "disabled", enable);    
+        cashflowManager.enableClass("btnCalculate", "disabled", enable && enableCalc);    
     }
 
     /**
